from resset.__init__ import *
import pandas as pd
import datetime

# 持久化对象
class Context():
    def __init__(self):
        # 账户信息
        self.permission = pd.DataFrame()
        self.userid = ''
    def __repr__(self):
        return "Context({'userid':%s})"\
               %(self.userid)
context = Context()

#判断是否登陆，剩余流量
def query_permission(id,tablename,startdate,enddate):
    persql = "select * from permission where userid='%s' and tablename='%s'"% (id,tablename)
    print(persql)
    context.permission = pd.read_sql_query(persql, dbengine)
    if len(context.permission)>0:
        p_start=context.permission['startdate'][0]
        p_enddate=context.permission['enddate'][0]
        p_totalnum=context.permission['totalnum'][0]
        p_eachnum=context.permission['eachnum'][0]
        if startdate != '':
            startdate_T = datetime.datetime.strptime(startdate, '%Y-%m-%d')
            if startdate_T >= p_start:
                startdate = startdate
            else:
                startdate = p_start.strftime("%Y-%m-%d %H:%M:%S")[:10]
        else:
            startdate = p_start.strftime("%Y-%m-%d %H:%M:%S")[:10]
        if enddate!='':
            enddate = enddate
        else:
            enddate = datetime.datetime.now().strftime("%Y-%m-%d %H:%M:%S")[:10]
        if p_totalnum > p_eachnum:
            num = p_eachnum
        else:
            num = p_totalnum
        return startdate,enddate,num
    else:
        print('该账号没有此表权限！！')
        exit()

def Islogin():
    if context.userid=='':
        print('请先登录账号！！')
        exit()



import hashlib
from resset.config import *

def md5x(pwd):
    try:
        # 或者可以这样
        mpwd=hashlib.md5(pwd).hexdigest()
    except:
        mpwd=hashlib.md5(pwd.encode(encoding='UTF-8')).hexdigest()
    return mpwd

def ressetLogin(loginname,loginpwd):
    pwd=md5x(loginpwd)
    sql="select id from rs_account where login_name='%s' and login_pwd='%s' "%(loginname,pwd)
    print(sql)
    cursor = db.cursor()
    cursor.execute(sql)
    id=cursor.fetchone()
    cursor.close()
    if id is not None:
        context.userid=id[0]
        print("登录成功！！")
    else:
        print('账户或密码错误！！')
if __name__ == '__main__':

    thsLogin = ressetLogin("zhangq", "123")
#     if (thsLogin == 0 or thsLogin == -201):


# -*- coding: utf-8 -*-
import pymssql
from resset.secret import *
from sqlalchemy import *
#solr地址
# titlesolr='http://106.75.219.243:8080/solrTA/title'
contentsolr=decrypt('36L39dqK+Yw2KxA8UiV39/smikvm7emHTaip6qjuUfdYXKLukGwaNjQQ9fb8Eap2')
# chaptersolr='http://106.75.219.243:8080/solrTA/chapter'
#TXT存储路径
PATH=u'E:/RESSET/Report'

#数据库链接
dburl=decrypt('BV4L6rzB5zITUPK+IeApvrgHUR96H64NfDz92potAnbpW57Yqh+jLn8PamZrnVF04gc/Xp3rkgj3Eu1tsFXpVWTu1Qh/hLqIy80zEleQ4r4')
db=pymssql.connect(decrypt('lLe1Js/ljrvNazOwGg0qPCn6QF1aNYoGLkl0Tu1k9Uw'), decrypt('QKQ4RAXfyse0+iqLFWewYA'), decrypt('p58sxNFfd1e4l1Eu66ZonA'), decrypt('lIPA8Yl8wzzwWDf9FdQe4g'), charset='utf8')
jydburl=decrypt('BV4L6rzB5zITUPK+IeApvkXu++2pLno6nj3cXSPKyha1t+vkWeZ5VGBdNb5KpnGtVKHMl/Tq73EqPtWA5AnPIg')
engine = create_engine(jydburl, echo=False, pool_size=1000)
dbengine=create_engine(dburl, echo=False, pool_size=1000)




from setuptools import setup
import setuptools
# setup(
#     name='ressetAPI',# 需要打包的名字,即本模块要发布的名字
#     version='v0.9.0',#版本
#     description='A  module for test', # 简要描述
#     py_modules=['resset',],   #  需要打包的模块
#     author='zhangq', # 作者名
#     author_email='569535175@qq.com',   # 作者邮件
#     url='https://github.com/vfrtgb158/email', # 项目地址,一般是代码托管的网站
#     # requires=['requests','urllib3'], # 依赖包,如果没有,可以不要
#     license='MIT'
# )
setup(
    name="resset",
    version="0.9.2",
    author="zhangq",
    author_email="569535175@qq.com",
    description="A small example package",
    url="https://github.com/PepperPapa/xinNotes",
    packages=setuptools.find_packages()
)